==> aws-cdk.aws-servicecatalogappregistry-1.146.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_servicecatalogappregistry_CfnAttributeGroupAssociationProps(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_CfnResourceAssociationProps(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_ApplicationProps(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_AttributeGroupProps(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_CfnApplicationProps(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_CfnAttributeGroupProps(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_IAttributeGroup(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_IApplication(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_CfnAttributeGroupAssociation(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_CfnResourceAssociation(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_AttributeGroup(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_CfnApplication(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_CfnAttributeGroup(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_Application(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_servicecatalogappregistry_CfnAttributeGroupAssociationProps, _aws_cdk_aws_servicecatalogappregistry_CfnResourceAssociationProps, _aws_cdk_aws_servicecatalogappregistry_ApplicationProps, _aws_cdk_aws_servicecatalogappregistry_AttributeGroupProps, _aws_cdk_aws_servicecatalogappregistry_CfnApplicationProps, _aws_cdk_aws_servicecatalogappregistry_CfnAttributeGroupProps, _aws_cdk_aws_servicecatalogappregistry_IAttributeGroup, _aws_cdk_aws_servicecatalogappregistry_IApplication, _aws_cdk_aws_servicecatalogappregistry_CfnAttributeGroupAssociation, _aws_cdk_aws_servicecatalogappregistry_CfnResourceAssociation, _aws_cdk_aws_servicecatalogappregistry_AttributeGroup, _aws_cdk_aws_servicecatalogappregistry_CfnApplication, _aws_cdk_aws_servicecatalogappregistry_CfnAttributeGroup, _aws_cdk_aws_servicecatalogappregistry_Application };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-servicecatalogappregistry-1.148.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_servicecatalogappregistry_CfnAttributeGroupAssociationProps(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_CfnResourceAssociationProps(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_ApplicationProps(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_AttributeGroupProps(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_CfnApplicationProps(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_CfnAttributeGroupProps(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_IAttributeGroup(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_IApplication(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_CfnAttributeGroupAssociation(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_CfnResourceAssociation(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_CfnApplication(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_AttributeGroup(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_CfnAttributeGroup(p) {
}
function _aws_cdk_aws_servicecatalogappregistry_Application(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_servicecatalogappregistry_CfnAttributeGroupAssociationProps, _aws_cdk_aws_servicecatalogappregistry_CfnResourceAssociationProps, _aws_cdk_aws_servicecatalogappregistry_ApplicationProps, _aws_cdk_aws_servicecatalogappregistry_AttributeGroupProps, _aws_cdk_aws_servicecatalogappregistry_CfnApplicationProps, _aws_cdk_aws_servicecatalogappregistry_CfnAttributeGroupProps, _aws_cdk_aws_servicecatalogappregistry_IAttributeGroup, _aws_cdk_aws_servicecatalogappregistry_IApplication, _aws_cdk_aws_servicecatalogappregistry_CfnAttributeGroupAssociation, _aws_cdk_aws_servicecatalogappregistry_CfnResourceAssociation, _aws_cdk_aws_servicecatalogappregistry_CfnApplication, _aws_cdk_aws_servicecatalogappregistry_AttributeGroup, _aws_cdk_aws_servicecatalogappregistry_CfnAttributeGroup, _aws_cdk_aws_servicecatalogappregistry_Application };
module.exports.DeprecationError = DeprecationError;
